<?php

namespace Teknisa\CRM\Factory;

use Doctrine\ORM\EntityManager;

class MauticFactory
{
    protected $connection;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
    }

    public function getParams()
    {
        $select = "SELECT CRM.DSPUBLICKEYMAUTIC, CRM.DSSECRETKEYMAUTIC, CRM.DSBASEURLMAUTIC, CRM.CDOPERULTATU, CRM.CDOPERINCLUSAO, INC.NRPARCNEGOCIO AS OPERINCLUSAO, ATU.NRPARCNEGOCIO AS OPERATUAL
                    FROM CRM_PARAMETRIZACAO CRM
                    LEFT JOIN OPERADOR INC
                    ON INC.CDOPERADOR = CRM.CDOPERINCLUSAO
                    LEFT JOIN OPERADOR ATU
                    ON ATU.CDOPERADOR = CRM.CDOPERULTATU";

        try {
            return $this->connection->query($select)->fetch();
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function searchUserEmail($userEmail)
    {
        try {
            $select = "SELECT CDOPERADOR, NRPARCNEGOCIO
                       FROM OPERADOR
                       WHERE UPPER(DSEMAILOPER) LIKE UPPER(:DSEMAILOPER)";

            $std = $this->connection->prepare($select);

            $params = array(
                "DSEMAILOPER" => $userEmail
            );

            $std->execute($params);
            return $std->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function getOperator()
    {
        $select = "SELECT CDOPERULTATU
                   FROM CRM_PARAMETRIZACAO
                   WHERE NRORG = :NRORG";

        try {
            return $this->connection->query($select)->fetch();
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function saveParamMautic($params)
    {
        $sql = 'UPDATE CRM_PARAMETRIZACAO
                SET DSPUBLICKEYMAUTIC = :DSPUBLICKEYMAUTIC,
                    DSSECRETKEYMAUTIC = :DSSECRETKEYMAUTIC,
                    DSBASEURLMAUTIC   = :DSBASEURLMAUTIC,
                    MAUTICAUTH        = :MAUTICAUTH,
                    DTULTATU          = SYSDATE,
                    CDOPERULTATU      = :CDOPERADOR,
                    NRORGULTATU       = :NRORGOPER
                WHERE NRORG           = :NRORG';

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getCompanyName($nrparceiro)
    {
        try {
            $select = "SELECT NMPRINCIPALPARC
                       FROM PARCNEGOCIO
                       WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";

            $std = $this->connection->prepare($select);

            $params = array(
                "NRPARCNEGOCIO" => $nrparceiro
            );
            $std->execute($params);
            return $std->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function getCompanyNr($nmparceiro)
    {
        try {
            $select = "SELECT NRPARCNEGOCIO
                       FROM PARCNEGOCIO
                       WHERE NMPRINCIPALPARC = :nmparceiro";

            $std = $this->connection->prepare($select);

            $params = array(
                "NRPARCNEGOCIO" => $nmparceiro
            );
            $std->execute($params);
            return $std->fetchAll();
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function novoInterlocutor()
    {
        $insert = "INSERT INTO ";
    }

    public function novoParcnegocio($row)
    {
        try {
            $insert = "INSERT INTO PARCNEGOCIO ( IDINSTITUICAO, IDPARCFUNDIDO, CDTIPOINSCRICAO, CDTIPOPARCPRINCIPAL, NRPARCNEGOCIO, NRORG, NMPRINCIPALPARC, NMSECUNDARIPARC, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, IDMAUTIC, CDOPERULTATU, CDOPERRESPONSAVEL, CDOPERINCLUSAO )
                        VALUES (:IDINSTITUICAO,
                                :IDPARCFUNDIDO,
                                :CDTIPOINSCRICAO,
                                :CDTIPOPARCPRINCIPAL,
                                :NRPARCNEGOCIO,
                                :NRORG,
                                :NMPRINCIPALPARC,
                                :NMSECUNDARIPARC,
                                :IDATIVO,
                                SYSDATE,
                                :NRORGINCLUSAO,
                                :IDMAUTIC,
                                :CDOPERULTATU,
                                :CDOPERRESPONSAVEL,
                                :CDOPERINCLUSAO )";

            $params = array(
                "IDINSTITUICAO"         => 'S',
                "IDPARCFUNDIDO"         => 'N',
                "CDTIPOINSCRICAO"       => 'LIVRE',
                "CDTIPOPARCPRINCIPAL"   => 'CANDIDATO',
                "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
                "NRORG"                 => $row["NRORG"],
                "NMPRINCIPALPARC"       => $row["NMPRINCIPALPARC"],
                "NMSECUNDARIPARC"       => $row["NMSECUNDARIPARC"],
                "IDATIVO"               => $row["IDATIVO"],
                "NRORGINCLUSAO"         => $row["NRORG"],
                "IDMAUTIC"              => $row["IDMAUTIC"],
                "CDOPERULTATU"          => $row["CDOPERULTATU"],
                "CDOPERRESPONSAVEL"     => $row["CDOPERRESPONSAVEL"],
                "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
            );

            $std = $this->connection->prepare($insert);
            $std->execute($params);
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function insertLead($row)
    {
        try {

            $insert = "INSERT INTO CRM_CANDIDATO
                        (IDATIVO, DTINCLUSAO, NRCANDIDATO, IDSTATUSCAN, IDTPIJURCAN, NMCANDIDATO, NMFANTCAN, NRPARCNEGOCIO, NRORG,  DTULTATU, NRORGINCLUSAO, IDPARCFUNDIDO, IDMAUTIC, CDOPERULTATU, CDOPERINCLUSAO, NRPARCPROPRI )
                        VALUES (:IDATIVO,
                                SYSDATE,
                                :NRCANDIDATO,
                                :IDSTATUSCAN,
                                :IDTPIJURCAN,
                                :NMCANDIDATO,
                                :NMFANTCAN,
                                :NRPARCNEGOCIO,
                                :NRORG,                                
                                SYSDATE,
                                :NRORGINCLUSAO,
                                :IDPARCFUNDIDO,
                                :IDMAUTIC,
                                :CDOPERULTATU,
                                :CDOPERINCLUSAO,
                                :NRPARCPROPRI)";

            $params = array(
                "IDATIVO"           => $row["IDATIVO"],
                "NRCANDIDATO"       => $row["NRCANDIDATO"],
                "IDSTATUSCAN"       => $row["IDSTATUSCAN"],
                "IDTPIJURCAN"       => $row["IDTPIJURCAN"],
                "NMCANDIDATO"       => $row["NMCANDIDATO"],
                "NMFANTCAN"         => $row["NMFANTCAN"],
                "NRPARCNEGOCIO"     => $row["NRPARCNEGOCIO"],
                "NRORG"             => $row["NRORG"],
                "NRORGINCLUSAO"     => $row["NRORGINCLUSAO"],
                "IDPARCFUNDIDO"     => $row["IDPARCFUNDIDO"],
                "IDMAUTIC"          => $row["IDMAUTIC"],
                "CDOPERULTATU"      => $row["CDOPERULTATU"],
                "CDOPERINCLUSAO"    => $row["CDOPERINCLUSAO"],
                "NRPARCPROPRI"      => $row["NRPARCPROPRI"],
            );

            $std = $this->connection->prepare($insert);
            $std->execute($params);
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function insertStatusParc($params)
    {
        try {
            $insert =  "INSERT INTO 
                        CRM_STATUSPARC (NRPARCNEGOCIO,
                                       STATUSPARC,
                                       NRORG,
                                       CRM_NRORGTRAB,
                                       IDATIVO,
                                       DTINCLUSAO,
                                       DTULTATU, 
                                       NRPARCRESP,
                                       CDOPERRESP,
                                       NRORGINCLUSAO,
                                       CDOPERULTATU,
                                       CDOPERINCLUSAO)
                        VALUES (:NRPARCNEGOCIO,
                                :STATUSPARC,
                                :NRORG,
                                :CRM_NRORGTRAB,
                                :IDATIVO,
                                SYSDATE,
                                SYSDATE,
                                :NRPARCRESP,
                                :CDOPERRESP,
                                :NRORGINCLUSAO,
                                :CDOPERULTATU,
                                :CDOPERINCLUSAO)";


            $params = array(
                "NRPARCNEGOCIO"         => $params["NRPARCNEGOCIO"],
                "STATUSPARC"            => $params["STATUSPARC"],
                "NRORG"                 => $params["NRORG"],
                "CRM_NRORGTRAB"         => $params["CRM_NRORGTRAB"],
                "IDATIVO"               => $params["IDATIVO"],
                "NRPARCRESP"            => $params["NRPARCRESP"],
                "CDOPERRESP"            => $params["CDOPERRESP"],
                "NRORGINCLUSAO"         => $params["NRORGINCLUSAO"],
                "CDOPERULTATU"          => $params["CDOPERULTATU"],
                "CDOPERINCLUSAO"        => $params["CDOPERINCLUSAO"],
            );

            $std = $this->connection->prepare($insert);
            $std->execute($params);
            return true;
        } catch (\Exception $e) {
            throw $e;
        };
    }


    public function verifyProspectName($params)
    {
        if (!empty($params['NMPRINCIPALPARC'])) {
            $select =  "SELECT  PARC.NRPARCNEGOCIO,
                                PARC.NMPRINCIPALPARC,
                                PARC.IDMAUTIC
                            FROM PARCNEGOCIO PARC
                        WHERE UPPER(PARC.NMPRINCIPALPARC) LIKE UPPER(:NOME)
                                AND PARC.NRORG = :NRORG";

            try {
                $stmt = $this->connection->prepare($select);

                $stmt->bindValue(':NOME', $params['NMPRINCIPALPARC']);
                $stmt->bindValue(':NRORG', $params['NRORG']);

                $stmt->execute();
                $lead = $stmt->fetchAll();

                return $lead;
            } catch (\Exception $e) {
                throw $e;
            }
        } else {
            return array();
        }
    }

    public function verifyProspectId($params)
    {
        if (!empty($params['IDMAUTIC'])) {
            $select =  "SELECT  NRPARCNEGOCIO,
                                NMPRINCIPALPARC,
                                IDMAUTIC
                            FROM PARCNEGOCIO 
                        WHERE IDMAUTIC =  :IDMAUTIC
                                AND NRORG = :NRORG";

            try {
                $stmt = $this->connection->prepare($select);

                $stmt->bindValue(':IDMAUTIC', $params['IDMAUTIC']);
                $stmt->bindValue(':NRORG', $params['NRORG']);

                $stmt->execute();
                $lead = $stmt->fetchAll();

                return $lead;
            } catch (\Exception $e) {
                throw $e;
            }
        } else {
            return array();
        }
    }

    public function searchCompanyByNR($params)
    {
        $select =  "SELECT  
                            IDMAUTIC
                        FROM PARCNEGOCIO 
                    WHERE NRPARCNEGOCIO =  :NRPARCNEGOCIO
                            AND NRORG = :NRORG";

        try {
            $stmt = $this->connection->prepare($select);

            $stmt->execute($params);
            $company = $stmt->fetchAll();

            return $company;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function verifyIdMautic($params)
    {
        if ($params) {
            $select =  "SELECT IDMAUTIC, EMAILINTERLOC, NRTELEFONE1
                            FROM CRM_INTERLOCUTOR
                        WHERE IDMAUTIC = :IDMAUTIC";
            try {
                $stmt = $this->connection->prepare($select);

                $stmt->bindValue(':IDMAUTIC', $params);

                $stmt->execute();
                $idMautic = $stmt->fetchAll();

                return $idMautic;
            } catch (\Exception $e) {
                throw $e;
            }
        } else {
            return array();
        }
    }

    public function insertInterlocutor($parameter)
    {

        try {
            $insert =  "INSERT INTO 
                        CRM_INTERLOCUTOR (IDMAUTIC, NRSEQINTERLOCUTOR, NMINTERLOCUTOR, NRTELEFONE1, EMAILINTERLOC, NRPARCNEGOCIO, NRORG, IDATIVO, DTINCLUSAO)
                        VALUES (
                            :IDMAUTIC,
                            :NRSEQINTERLOCUTOR,
                            :NMINTERLOCUTOR,
                            :NRTELEFONE1,
                            :EMAILINTERLOC,
                            :NRPARCNEGOCIO,
                            :NRORG,
                            :IDATIVO,
                            SYSDATE)";

            if (!empty($parameter)) {
                $params = array(
                    "IDMAUTIC"          => $parameter["IDMAUTIC"],
                    "NRSEQINTERLOCUTOR" => $parameter["NRSEQINTERLOCUTOR"],
                    "NMINTERLOCUTOR"    => $parameter["NMINTERLOCUTOR"],
                    "NRTELEFONE1"       => $parameter["NRTELEFONE1"],
                    "EMAILINTERLOC"     => $parameter["EMAILINTERLOC"],
                    "NRPARCNEGOCIO"     => $parameter["NRPARCNEGOCIO"],
                    "NRORG"             => $parameter["NRORG"],
                    "IDATIVO"           => $parameter["IDATIVO"]
                );
            }

            $std = $this->connection->prepare($insert);
            $std->execute($params);
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function updateInterlocutor($parameter)
    {
        try {
            $update = "UPDATE CRM_INTERLOCUTOR 
                   SET 
                        NMINTERLOCUTOR = :NMINTERLOCUTOR, 
                        NRTELEFONE1    = :NRTELEFONE1, 
                        EMAILINTERLOC  = :EMAILINTERLOC, 
                        NRORG          = :NRORG, 
                        IDATIVO        = :IDATIVO, 
                        DTULTATU       = SYSDATE
                   WHERE IDMAUTIC = :IDMAUTIC";


            $params = array(
                "NMINTERLOCUTOR" => $parameter["NMINTERLOCUTOR"],
                "NRTELEFONE1"    => $parameter["NRTELEFONE1"],
                "EMAILINTERLOC"  => $parameter["EMAILINTERLOC"],
                "NRORG"          => $parameter["NRORG"],
                "IDATIVO"        => $parameter["IDATIVO"],
                "IDMAUTIC"       => $parameter["IDMAUTIC"]
            );


            $std = $this->connection->prepare($update);
            $std->execute($params);
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function updateParcnegocio($parameter)
    {
        try {

            $update = "UPDATE PARCNEGOCIO
                   SET 
                        NMPRINCIPALPARC = :NMPRINCIPALPARC, 
                        DTULTATU        = SYSDATE,
                        IDMAUTIC        = :IDMAUTIC
                   WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                             AND NRORG = :NRORG";

            $params = array(
                "NMPRINCIPALPARC" => $parameter["NMPRINCIPALPARC"],
                "IDMAUTIC"          => $parameter["IDMAUTIC"],
                "NRPARCNEGOCIO"     => $parameter["NRPARCNEGOCIO"],
                "NRORG"             => $parameter["NRORG"],
            );

            $std = $this->connection->prepare($update);
            $std->execute($params);



            $update = "UPDATE CRM_CANDIDATO
                   SET 
                        NMCANDIDATO = :NMCANDIDATO, 
                        NMFANTCAN   = :NMCANDIDATO,
                        DTULTATU    = SYSDATE,
                        IDMAUTIC    = :IDMAUTIC
                   WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                             AND NRORG = :NRORG";

            $params = array(
                "NMCANDIDATO"       => $parameter["NMPRINCIPALPARC"],
                "IDMAUTIC"          => $parameter["IDMAUTIC"],
                "NRPARCNEGOCIO"     => $parameter["NRPARCNEGOCIO"],
                "NRORG"             => $parameter["NRORG"],
            );

            $std = $this->connection->prepare($update);
            $std->execute($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }




    /* 
    // Inserir um novo lead
    public function insert($params)
    {
        $insert = "INSERT INTO PARCNEGOCIO (NRPARCNEGOCIO, NRORG, NMPRINCIPALPARC, NMSECUNDARIPARC, NRINSCRICAOPARC, IDATIVO, DTINCLUSAO,
                         NRORGINCLUSAO, CDOPERINCLUSAO, CDTIPOPARCPRINCIPAL, CDTIPOINSCRICAO,IDPESSOAFISICA)
         VALUES (:NRPARCNEGOCIO,
                 :NRORG,
                 :NMPRINCIPALPARC,
                 :NMSECUNDARIPARC,
                 :NRINSCRICAOPARC,
                 :IDATIVO,
                  SYSDATE,
                 :NRORGINCLUSAO,
                 :CDOPERINCLUSAO,
                 :CDTIPOPARCPRINCIPAL,
                 :CDTIPOINSCRICAO,
                 :IDPESSOAFISICA)";

        $params = array(
            "IDATIVO"               => $row["IDATIVO"],
            "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"],
            "NMPRINCIPALPARC"       => $row["NMCANDIDATO"],
            "NMSECUNDARIPARC"       => $row["NMFANTCAN"],
            "NRINSCRICAOPARC"       => $row["NRINSJURCAN"],
            "NRORGINCLUSAO"         => $row["NRORG"],
            "CDOPERINCLUSAO"        => $row["CDOPEREVOL"],
            "CDTIPOPARCPRINCIPAL"   => "CANDIDATO",
            "CDTIPOINSCRICAO"       => $row["TIPOINSC"],
            "IDPESSOAFISICA"        => $row["ISCPF"],
        );

        try {
            $stmt = $this->connection->prepare($insert);
            $stmt->execute($params);
            return ['id' => $this->connection->lastInsertId(), 'name' => $params['name'], 'email' => $params['email']];
        } catch (\Exception $e) {
            throw $e;
        };   
    } */
}
