<?php

namespace Teknisa\CRM\Service;

use InvalidArgumentException;
use Teknisa\Libs\Util\Environment;

use Teknisa\CRM\Factory\MauticFactory;
use Teknisa\CRM\Util\API\MauticAPI;


class MauticService
{
    protected $mauticFactory;
    protected $mauticAPI;
    protected $newCode;
    protected $environment;

    public function __construct(MauticFactory $mauticFactory, MauticAPI $mauticAPI, $newCode, Environment $environment )
    {
        $this->mauticFactory    = $mauticFactory;
        $this->mauticAPI        = $mauticAPI;
        $this->newCode          = $newCode;
        $this->environment      = $environment;
    }

    public function getParams()
    {
        $dadosApi = $this->mauticFactory->getParams();
        $this->mauticAPI->conection($dadosApi);  
    }

    public function getUser($id)
    {
        $this->getParams();

        $userMautic = $this->mauticAPI->getMauticUser($id);

        if(isset($userMautic['user']) && isset($userMautic['user']['email'])){
            $userCRM = $this->mauticFactory->searchUserEmail($userMautic['user']['email']);

            if(!empty($userCRM)){
               $this->mauticAPI->setUser($userCRM[0]);
            }
        }

        return $this->mauticAPI->getUser();
    }


    public function saveParamMautic($row)
    {

        $nrorg = $this->environment->getNrOrgTrab();
        $cdoperador = $this->environment->getCdOperador();
        $nrorgOper = $this->environment->getNrOrg();

        $params = array(
            "DSPUBLICKEYMAUTIC" => $row['DSPUBLICKEYMAUTIC'],
            "DSSECRETKEYMAUTIC" => $row['DSSECRETKEYMAUTIC'],
            "DSBASEURLMAUTIC"   => $row['DSBASEURLMAUTIC'],
            "MAUTICAUTH"        => $row['MAUTICAUTH'],
            "NRORG"             => $nrorg,
            "CDOPERADOR"        => $cdoperador,
            "NRORGOPER"         => $nrorgOper
        );

        $this->mauticFactory->saveParamMautic($params);
    }

    public function getLeads()
    {
        try {
            $this->getParams();
            return $this->getUser(2);

        } catch (\Throwable $th) {
            return null;
        }
    }

    public function getCompanies()
    {
        try {
            $this->getParams();

            return $this->mauticAPI->getCompany(58);

        } catch (\Throwable $th) {
            return null;
        }
    }

    public function createContact($params)
    {
        try {
            $this->getParams();

            $companyName = $this->mauticFactory->getCompanyName($params['NRPARCNEGOCIO']);

            $createdContact = $this->mauticAPI->createContact($params, $companyName[0]);

            return $createdContact['contact']['id'];
        } catch (\Throwable $th) {
            return null;
        }
    }

    public function editContact($params)
    {
        try {
            $this->getParams();

            $companyName = $this->mauticFactory->getCompanyName($params['NRPARCNEGOCIO']);
            $this->mauticAPI->editContact($params, $companyName[0]);

        } catch (\Throwable $th) {
            return null;
        }
    }

    public function novoInterlocutor($params)
    {
        try {           
           foreach ($params as $contact) {
               $novoContato = $contact['contact'] ?? null;

               if ($novoContato && ($novoContato['modifiedBy'] != null || ($novoContato['owner'] != null && $novoContato['dateAdded'] == $novoContato['dateModified'])))
               {
                    $operator = $this->getUser($novoContato['createdBy']);

                    $id             = $novoContato['id'];
                    $contactExist = $this->searchInterlocutor($id);

                    if (empty($contactExist)) {

                        $name       = $novoContato['firstname'] ?? '';
                        $company    = $novoContato['company'] ?? '';
                        $email      = $novoContato['email'] ?? '';
                        $mobile     = $novoContato['mobile'] ?? '';

                        if ($company && !empty($company)) {
                            $companySearch = $this->searchParc([
                                'NMPRINCIPALPARC' => $company,
                                'NRORG'          => 20
                            ]);
                        }

                        if (empty($companySearch)) {
                            $newProspect = [
                                [
                                    'company' => [
                                        'name' => $company
                                    ]
                                ]
                            ];

                            $newCompany = $this->saveProspect($newProspect);
                        }

                        $dataToInsert = [
                            'IDMAUTIC'       => $id,
                            'NMINTERLOCUTOR' => $name,
                            'EMAILINTERLOC'  => $email,
                            'NRTELEFONE1'    => $mobile,
                            'NMPRINCIPALPARC' => $company,
                            'NRSEQINTERLOCUTOR'  => $this->newCode->getCodeByTableName("CRM_INTERLOCUTOR", 20),
                            'NRORG'          => 20,
                            'NRPARCNEGOCIO'  => !empty($companySearch) ? $companySearch[0]['NRPARCNEGOCIO'] : $newCompany,
                            'IDATIVO'        => 'S',
                            'CDOPERULTATU'   => $operator['CODOPER'],
                            'CDOPERRESPONSAVEL' => $operator['CODOPER'],
                            'CDOPERINCLUSAO'    => $operator['CODOPER'], 
                        ];

                        $this->mauticFactory->insertInterlocutor($dataToInsert);

                    } else {

                        $name       = $novoContato['fields']['core']['firstname']['value'] ?? '';
                        $company    = $novoContato['fields']['core']['company']['value'] ?? '';
                        $email      = $novoContato['fields']['core']['email']['value'] ?? '';
                        $mobile     = $novoContato['fields']['core']['mobile']['value'] ?? '';

                        $dataToInsert = [
                            'IDMAUTIC'       => $id,
                            'NMINTERLOCUTOR' => $name,
                            'EMAILINTERLOC'  => $email,
                            'NRTELEFONE1'    => $mobile,
                            'NMPRINCIPALPARC' => $company,
                            'NRORG'          => 20,
                            'IDATIVO'        => 'S',
                            'CDOPERULTATU'   => $operator,
                            'CDOPERRESPONSAVEL' => $operator,
                            'CDOPERINCLUSAO'    => $operator, 
                        ];

                        $this->mauticFactory->updateInterlocutor($dataToInsert);
                    }
                }
            }
        } catch (\Throwable $th) {
            return null;
        }
    }

    public function saveProspect($params)
    {
        try {
            
            foreach ($params as $company) {
                $companyData = $company['company'] ?? null;
                
                if (
                    $companyData &&
                    !empty($companyData['PastChanges']) && 
                    (   ($companyData['modifiedBy'] != null && 
                        $companyData['dateModified'] != null) ||
                        ($companyData['createdBy'] != null && 
                        $companyData['dateModified'] == null)
                    ))
                    {

                    $operator = $this->getUser($companyData['createdBy']);
                    
                    $changes = $companyData['PastChanges']['fields'];
                    
                    $companyNameSearch = isset($changes['companyname']) && $changes['companyname'][0] ? $changes['companyname'][0] : $companyData['name'];
                    
                    $companySearch = $this->searchParcId([
                        'NRORG'          => 20,
                        'IDMAUTIC'       => $companyData['id'],
                    ]);
                    
                    if (empty($companySearch)) {
                        $companySearch = $this->searchParc([
                            'NMPRINCIPALPARC' => $companyNameSearch,
                            'NRORG'          => 20,
                        ]);
                    }
                    
                    
                    if ((isset($changes['companyname']) && !($changes['companyname'][0]) && empty($companySearch)) || empty($companySearch)) {
                        $nrparceiro     = $this->newCode->getCodeByTableName("PARCNEGOCIO", 20);
                        $nrcandidato    = $this->newCode->getCodeByTableName("CANDIDATO9999", 20);
                        
                        $insertParc = [
                            'IDINSTITUICAO'         => 'S',
                            'IDPARCFUNDIDO'         => 'N',
                            'CDTIPOINSCRICAO'       => 'LIVRE',
                            "CDTIPOPARCPRINCIPAL"   => 'CANDIDATO',
                            'NRPARCNEGOCIO'         => $nrparceiro,
                            'NRORG'                 => 20,
                            'NMPRINCIPALPARC'       => $companyData['name'],
                            'NMSECUNDARIPARC'       => $companyData['name'],
                            'IDATIVO'               => 'S',
                            'NRORGINCLUSAO'         => 20,
                            'IDMAUTIC'              => $companyData['id'],
                            'CDOPERULTATU'          => $operator['CODOPER'],
                            'CDOPERRESPONSAVEL'     => $operator['CODOPER'],
                            'CDOPERINCLUSAO'        => $operator['CODOPER'],
                        ];
                        
                        $this->mauticFactory->novoParcnegocio($insertParc);

                        $insertLead = [
                            'IDATIVO'           => 'S',
                            'IDSTATUSCAN'       => '2',
                            'IDPARCFUNDIDO'     => 'N',
                            'NMCANDIDATO'       => $companyData['name'],
                            'NMFANTCAN'         => $companyData['name'],
                            'NRCANDIDATO'       => $nrcandidato,
                            'NRPARCNEGOCIO'     => $nrparceiro,
                            'NRORG'             => 20,
                            'IDOPERATIVO'       => 'A',
                            "IDTPIJURCAN"       => 'I',
                            "NRORGINCLUSAO"     => 20,
                            'IDMAUTIC'          => $companyData['id'],
                            'CDOPERULTATU'      => $operator['CODOPER'],
                            'CDOPERINCLUSAO'    => $operator['CODOPER'],
                            'NRPARCPROPRI'      => $operator['NRPAR']
                        ];
                        $this->mauticFactory->insertLead($insertLead);

                        $insertStatus = [
                            'NRPARCNEGOCIO'     => $nrparceiro,
                            'STATUSPARC'        => 'CANDIDATO',
                            'NRORG'             => 20,
                            'CRM_NRORGTRAB'     => 20,
                            "NRORGINCLUSAO"     => 20,
                            'IDATIVO'           => 'S',
                            'NRPARCRESP'        => $operator['NRPAR'],
                            'CDOPERRESP'        => $operator['CODOPER'],
                            'CDOPERULTATU'      => $operator['CODOPER'],
                            'CDOPERINCLUSAO'    => $operator['CODOPER'],
                        ];
                        
                        $this->mauticFactory->insertStatusParc($insertStatus);
                    } else {
                        // em caso de ediçao
                        $updatedParcnegocio = [];

                        foreach ($changes as $field => $change) {
                            $mappedField = $this->mapFieldName($field);

                            if ($mappedField) { // Apenas campos mapeados
                                $updatedParcnegocio[$mappedField] = $change[1];
                            }
                        }

                        // Atualizar parceiro (PARCNEGOCIO)
                        if (!empty($updatedParcnegocio)) {

                            $params = array_merge([
                                'IDATIVO'        => 'S',
                                'NRPARCNEGOCIO'  => $companySearch[0]['NRPARCNEGOCIO'],
                                'NRORG'          => 20,
                                'IDMAUTIC'       => $companySearch[0]['IDMAUTIC'] ? $companySearch[0]['IDMAUTIC'] : $companyData['id'],
                            ], $updatedParcnegocio);

                            $this->mauticFactory->updateParcnegocio($params);
                        }
                    }
                }
            }
        } catch (\Throwable $th) {
            return null;
        }
    }

    private function mapFieldName($field)
    {
        $fieldMap = [
            'companyname'    => 'NMPRINCIPALPARC'
        ];

        return $fieldMap[$field] ?? null;
    }

    public function searchParc($companyData)
    {
        return $this->mauticFactory->verifyProspectName($companyData);
    }

    public function searchParcId($companyData)
    {
        return $this->mauticFactory->verifyProspectId($companyData);
    }

    public function searchInterlocutor($idMautic)
    {
        return $this->mauticFactory->verifyIdMautic($idMautic);
    }

    public function searchCompanyByNR($companyData){
        $params = [
            'NRPARCNEGOCIO' => $companyData['NRPARCNEGOCIO'],
            'NRORG' => $companyData['NRORG'],
        ];

        $company = $this->mauticFactory->searchCompanyByNR($params);

        return empty($company) ? null : $company[0]['IDMAUTIC'];
    }

    public function createCompany($company)
    {
        try {
            $idmautic = $this->searchCompanyByNR($company);
            $this->getParams();
            
            if($idmautic){
                $this->mauticAPI->editCompany($idmautic, $company['NMCANDIDATO']);
                return $idmautic;
            } else {
                $newCompany = $this->mauticAPI->createCompany($company['NMCANDIDATO']);
                return $newCompany['company']['id'];
            }                
        } catch (\Throwable $th) {
            return null;
        }
    }
}
