<?php

namespace Teknisa\CRM\Util\API;

class MauticAPI
{
    private $authentication;
    private $keyPublic;
    private $keyPrivate;
    private $endpoint;
    private $user;

    public function getAuthentication()
    {
        set_time_limit(180);

        $body = array();
        $body['grant_type'] = 'client_credentials';
        $body['client_id'] = $this->keyPublic;
        $body['client_secret'] = $this->keyPrivate;

        $ch = curl_init();

        curl_setopt_array($ch, array(
            CURLOPT_URL => $this->endpoint.'oauth/v2/token',
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => 'POST',
            CURLOPT_POSTFIELDS => http_build_query($body), 
            CURLOPT_HTTPHEADER => array(
                'Content-Type: application/x-www-form-urlencoded'
            ),
        ));

        $resultado = curl_exec($ch);

        // Verifique erros de cURL
        if ($resultado === false) {
            throw new \Exception('Erro de cURL: ' . curl_error($ch));
        }

        // Decode do JSON
        $resultado = json_decode($resultado, true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new \Exception('Erro ao decodificar JSON: ' . json_last_error_msg());
        }

        // Verifique erros retornados pela API
        if (!empty($resultado["error"])) {
            throw new \Exception('Erro na autenticação: ' . $resultado["error_description"]);
        }

        curl_close($ch);

        $this->authentication = $resultado;
    }


    public function conection($dadosApi)
    {
        $this->keyPublic = $dadosApi['DSPUBLICKEYMAUTIC'];
        $this->keyPrivate = $dadosApi['DSSECRETKEYMAUTIC'];
        $this->endpoint = $dadosApi['DSBASEURLMAUTIC'];
        $this->user = [
            'CODOPER'   => $dadosApi['CDOPERULTATU'] ? $dadosApi['CDOPERULTATU'] : $dadosApi['CDOPERINCLUSAO'],
            'NRPAR'     => $dadosApi['OPERATUAL'] ? $dadosApi['OPERATUAL'] : $dadosApi['OPERINCLUSAO'],            
        ];

        self::getAuthentication();
    }

    public function getUser()
    {
        return $this->user;
    }

    public function setUser($cdoperador)
    {
        $this->user = $cdoperador;
        $this->user = [
            'CODOPER'   => $cdoperador['CDOPERADOR'] ,
            'NRPAR'     => $cdoperador['NRPARCNEGOCIO'],            
        ];
    }

    

    public function makeRequest($router, $typeRequest = 'GET', $params = [])
    { 
        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => $this->endpoint.$router,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => $typeRequest,
            CURLOPT_HTTPHEADER => array(
                'Authorization: Bearer ' . $this->authentication['access_token']
            ),
        ));

        if(!empty($params)){            
            curl_setopt_array($curl, array(            
                CURLOPT_POSTFIELDS => http_build_query($params)             
            ));
        }


        $response = curl_exec($curl);
        $response = json_decode($response, true);

        curl_close($curl);

        if (!empty($response["error"])) {
            throw new \Exception($response["error"]);
        } else if (!empty($error)) {
            throw new \Exception($error);
        } else {
            return $response;
        }
    }

    /*
    -----------------------------
        ROTAS
    -----------------------------
    */
    public function getMauticUser($id)
    {
        return $this->makeRequest('api/users' . '/' . $id);
    }

    public function getContacts()
    {
        return $this->makeRequest("contacts");
    }


    public function createContact($infoContact, $companyName)
    {
        return $this->makeRequest("api/contacts/new", 'POST', [
            'mobile'    => $infoContact['NRTELEFONE1'],
            'email'     => $infoContact['EMAILINTERLOC'],
            'firstname' => $infoContact['NMINTERLOCUTOR'],
            'company'   => $companyName['NMPRINCIPALPARC'],
        ]);
    }

    public function editContact($params, $companyName)
    {
        $status = ($params['IDATIVO'] == 'N') ? 'Inativo' : 'Ativo';

        $contact = [
            'id'          => $params['IDMAUTIC'],
            'mobile'      => $params['NRTELEFONE1'],
            'email'       => $params['EMAILINTERLOC'],
            'firstname'   => $params['NMINTERLOCUTOR'],
            'company'     => $companyName['NMPRINCIPALPARC'],
            'tags'        => $status,
        ];

        return $this->makeRequest('api/contacts' . '/' . $params['IDMAUTIC'] . '/edit', 'PATCH', $contact);
    }

    public function getCompany($id)
    {
        return $this->makeRequest("api/companies" . '/' . $id);
    }


    public function createCompany($candidato)
    {
        return $this->makeRequest("api/companies/new", 'POST', [
            'companyname' => $candidato,
        ]);
    }

    public function editCompany($id, $candidato)
    {
        return $this->makeRequest("api/companies/".$id.'/edit', 'PUT', [
            'companyname' => $candidato,
        ]);
    }

}
